@@ -14,12 +14,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__version__ = "0.2.0"
 
-import distutils
+from shutil import which
 import os
 import subprocess
 import sys
+from importlib import metadata
+
+__version__ = metadata.version(__package__)
 
 
 def is_program(name):
@@ -31,7 +33,7 @@ def is_program(name):
     :returns: whether or not the program can be found in $PATH
     :rtype: bool
     """
-    return distutils.spawn.find_executable(name) is not None
+    return which(name) is not None
 
 
 def find_subcommand(args):
